@@ -21,8 +21,7 @@ import os
 from pyrocumulus.commands.base import BaseCommand
 
 
-SETUP_TEMPLATE = """
-#-*- coding: utf-8 -*-
+SETUP_TEMPLATE = """#-*- coding: utf-8 -*-
 
 from setuptools import setup, find_packages
 
@@ -40,18 +39,17 @@ setup(name='%(name)s',
           'Development Status :: 3 - Alpha',
           'Programming Language :: Python :: 3',
       ],
+      test_suite='tests',
       provides=['%(name)s'],
 )
 """
 
-TESTS_TEMPLATE = """
-#-*- coding: utf-8 -*-
+TESTS_TEMPLATE = """#-*- coding: utf-8 -*-
 
 import unittest
 """
 
-PYROMANAGER_TEMPLATE = """
-#!/usr/bin/env python
+PYROMANAGER_TEMPLATE = """#!/usr/bin/env python
 #-*- coding: utf-8 -*-
 
 from pyrocumulus.commands.base import run_command
@@ -60,23 +58,55 @@ run_command()
 
 """
 
+SETTINGS_TEMPLATE = """#-*- coding: utf-8 -*-
 
+PROJECT_NAME = '%(name)s'
+
+DATABASE = {'default': {'host': 'localhost',
+                        'port': 27017,
+                        'db': 'pyrocumulus'}}
+
+DEBUG = True
+"""
+
+MODELS_TEMPLATE = """#-*- coding: utf-8 -*-
+
+"""
+
+WEB_TEMPLATE = """#-*- coding: utf-8 -*-
+
+from tornado.web import Application
+
+
+"""
+
+INIT_TEMPLATE = """#-*- coding: utf-8 -*-
+
+from pyrocumulus.db import MongoConnection
+
+connection = MongoConnection()
+connection.connect()
+
+"""
 class CreateProjectCommand(BaseCommand):
 
     user_options = [
         # path
         {'args': ('path',),
          'kwargs': {'help': 'Path for this project'}},
-        # --project-name=name
+        # --project-name name
         {'args': ('--project-name',),
          'kwargs': {'default': None, 'nargs': '?',
                     'help': 'Project\'s name'}}
-]
+    ]
 
     def run(self):
-        self.name = self.name or os.path.dirname(self.path)
+        self.project_name = self.project_name or \
+            self.path.split(os.sep)[-1]
+
         self.path = os.path.abspath(self.path)
-        self.package_path = os.path.join(self.path, self.name)
+        print('creating new project at %s...' % self.path)
+        self.package_path = os.path.join(self.path, self.project_name)
 
         try:
             os.mkdir(self.path)
@@ -89,6 +119,10 @@ class CreateProjectCommand(BaseCommand):
             template = SETUP_TEMPLATE % {'name': self.project_name}
             f.write(template)
 
+        with open(os.path.join(self.path, 'settings.py'), 'w') as f:
+            template = SETTINGS_TEMPLATE % {'name': self.project_name}
+            f.write(template)
+
         with open(os.path.join(self.path, 'tests.py'), 'w') as f:
             f.write(TESTS_TEMPLATE)
 
@@ -96,4 +130,10 @@ class CreateProjectCommand(BaseCommand):
             f.write(PYROMANAGER_TEMPLATE)
 
         with open(os.path.join(self.package_path, '__init__.py'), 'w') as f:
-            f.write('''#-*- coding: utf-8 -*-\n''')
+            f.write(INIT_TEMPLATE)
+
+        with open(os.path.join(self.package_path, 'models.py'), 'w') as f:
+            f.write(MODELS_TEMPLATE)
+
+        with open(os.path.join(self.package_path, 'web.py'), 'w') as f:
+            f.write(WEB_TEMPLATE)
