@@ -31,12 +31,14 @@ class BaseRequestHandler(RequestHandler):
     for automatic api creation.
     """
 
-    def initialize(self, model):
+    def initialize(self, model, cors_origins=None):
         """
         Method called after the class' constructor. Initializes
         the model and parses it.
 
         :param model: mongoengine Document subclass
+        :param cors_origin: Value to "Access-Control-Allow-Origin" header.
+                            If not cors_origin, cors is disabled.
         """
         self.model = model
         parser = get_parser(self.model)
@@ -45,6 +47,11 @@ class BaseRequestHandler(RequestHandler):
         self.model_embedded_documents = self.parsed_model['embedded_documents']
         self.model_list_fields = self.parsed_model['list_fields']
 
+        self.cors_origins = cors_origins
+        self.cors_enabled = True if self.cors_origins else False
+        if self.cors_enabled:
+            self._enable_cors()
+
     def prepare(self):
         """
         Method called in the beginnig of every request.
@@ -61,6 +68,9 @@ class BaseRequestHandler(RequestHandler):
         converter = get_request_converter(self.request.arguments, self.model)
         return converter.to_dict()
 
+    def _enable_cors(self):
+        self.set_header("Access-Control-Allow-Origin", self.cors_origins)
+
     def get(self):  # pragma: no cover
         """
         Method called on GET requests.
@@ -97,6 +107,15 @@ class BaseRequestHandler(RequestHandler):
 
         raise NotImplementedError
 
+    def options(self):  # pragma: no cover
+        """
+        Method called on OPTIONS requests.
+
+        Subclasses must implement it.
+        """
+
+        raise NotImplementedError
+
     @classmethod
     def embeddedhandler(cls):  # pragma no cover
         """
@@ -111,7 +130,7 @@ class RestHandler(BaseRequestHandler):
     Request handler for rest applications
     """
 
-    def initialize(self, model, object_depth=1):
+    def initialize(self, model, object_depth=1, *args, **kwargs):
         """
         :param model: mongoengine Document subclass.
         :param object_depth: depth of the object, meaning how many
@@ -120,17 +139,20 @@ class RestHandler(BaseRequestHandler):
 
         Initializes object_depth and call initialize_extra_handlers().
         """
-        super(RestHandler, self).initialize(model)
+        super(RestHandler, self).initialize(model, *args, **kwargs)
         self.object_depth = object_depth
         self.operations = {'list': self.list_objects,
                            'get': self.get_object,
                            'put': self.put_object,
-                           'delete': self.delete_object}
+                           'delete': self.delete_object,
+                           'options': self.send_options}
+
         # allowed operations by request method
         self.allowed_operations = {'get': ['get', 'list'],
                                    'post': ['put', 'delete'],
                                    'put': ['put'],
-                                   'delete': ['delete']}
+                                   'delete': ['delete'],
+                                   'options': ['options']}
 
         # extra handlers used with EmbeddedDocuments and ListFields
         self.initialize_extra_handlers()
@@ -188,6 +210,19 @@ class RestHandler(BaseRequestHandler):
                                                   allowed_operations)
         self.call_method_and_write_json(method_to_call)
 
+    def options(self, operation):
+        """
+        Method called on OPTIONS requests.
+
+        Subclasses must implement it.
+        """
+        allowed_operations = self.get_allowed_operations('options')
+        operation = operation or 'options'
+        method_to_call = self._validade_operation(operation,
+                                                  allowed_operations)
+        returned = method_to_call(**self.params)
+        self.write(returned)
+
     def call_method_and_write_json(self, method_to_call):
         """
         Call the method for the requested action and writes
@@ -214,12 +249,18 @@ class RestHandler(BaseRequestHandler):
         if self.model_embedded_documents:
             pass
 
+    def send_options(self, **kwargs):
+        self.set_header('Access-Control-Allow-Headers', '*')
+        self.set_header('Access-Control-Allow-Methods',
+                        'GET, POST, PUT, DELETE, OPTIONS')
+        return {'corsEnabled': True}
+
     def list_objects(self, **kwargs):
         """
         Method that returns a list of objects. Called by
         get()
         """
-        # removing lists from args to filter()
+        # removing lists from args passed to filter()
         clean_kwargs = {}
         for key, value in kwargs.items():
             if isinstance(value, list):
@@ -263,6 +304,9 @@ class RestHandler(BaseRequestHandler):
         return self.allowed_operations[method]
 
     def get_callback(self):
+        """
+        Returns the callback name to be used on jsonp requests
+        """
         callback = self.request.arguments.get('callback') or None
         if callback:
             callback = callback[0]
@@ -320,7 +364,7 @@ class ReadOnlyRestHandler(RestHandler):
 
 
 class EmbeddedDocumentHandler(RestHandler):
-    def initialize(self, parent_doc, model, object_depth=1):
+    def initialize(self, parent_doc, model, object_depth=1, *args, **kwargs):
         super(EmbeddedDocumentHandler, self).initialize(model, object_depth)
         self.parent_doc = parent_doc
         self.parsed_parent = get_parser(self.parent_doc).parse()
