@@ -17,6 +17,7 @@
 
 from tornado.web import URLSpec
 from pyrocumulus import utils
+from pyrocumulus.conf import settings
 from pyrocumulus.parsers import get_parser
 
 
@@ -89,7 +90,11 @@ class DocumentURLMapper:
         """
         Get kwargs to be passed to request handler
         """
-        return dict(model=self.document)
+        kwargs = dict(model=self.document)
+        if hasattr(settings, 'CORS_ORIGINS') and settings.CORS_ORIGINS:
+            kwargs.update({'cors_origins': settings.CORS_ORIGINS})
+
+        return kwargs
 
     def get_url_pattern(self, prefix=''):
         """
